# SAMPIClyser
Python library to help decoding and analysing data from a SAMPIC system

You can install the SAMPIClyser libraries with: `python -m pip install SAMPIClyser`

After installation, you can run the individual tools with their dedicated commands:
 * ``sampiclyser-version`` - To print the version of the SAMPIClyser library in use
 * ``sampic-convert`` - To read the binary files and save them in a standard format
